"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintNFT = void 0;
const web3_js_1 = require("@solana/web3.js");
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const assert_1 = require("assert");
const createTokenAccount_1 = require("../transactions/createTokenAccount");
const createMetadata_1 = require("./createMetadata");
const createMintAccount_1 = require("./createMintAccount");
const URI = 'https://arweave.net/Rmg4pcIv-0FQ7M7X838p2r592Q4NU63Fj7o7XsvBHEE';
const NAME = 'test';
const SYMBOL = 'sym';
const SELLER_FEE_BASIS_POINTS = 10;
async function mintNFT({ transactionHandler, payer, connection, creators }) {
    const { mint, createMintTx } = await createMintAccount_1.CreateMint.createMintAccount(connection, payer.publicKey);
    const mintRes = await transactionHandler.sendAndConfirmTransaction(createMintTx, [mint], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, mintRes.txConfirmed);
    const { tokenAccount, createTokenTx } = await (0, createTokenAccount_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: mint.publicKey,
        connection,
    });
    createTokenTx.add(spl_token_1.Token.createMintToInstruction(new web3_js_1.PublicKey(spl_token_1.TOKEN_PROGRAM_ID), mint.publicKey, tokenAccount.publicKey, payer.publicKey, [], 1));
    const associatedTokenAccountRes = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [tokenAccount], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, associatedTokenAccountRes.txConfirmed);
    const initMetadataData = new mpl_token_metadata_1.MetadataDataData({
        uri: URI,
        name: NAME,
        symbol: SYMBOL,
        sellerFeeBasisPoints: SELLER_FEE_BASIS_POINTS,
        creators: creators !== null && creators !== void 0 ? creators : null,
    });
    const { createTxDetails } = await (0, createMetadata_1.createMetadata)({
        transactionHandler,
        publicKey: payer.publicKey,
        editionMint: mint.publicKey,
        metadataData: initMetadataData,
    });
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, createTxDetails.txConfirmed);
    const metadataPDA = await mpl_token_metadata_1.Metadata.getPDA(mint.publicKey);
    const [edition, editionBump] = await web3_js_1.PublicKey.findProgramAddress([
        Buffer.from(mpl_token_metadata_1.MetadataProgram.PREFIX),
        mpl_token_metadata_1.MetadataProgram.PUBKEY.toBuffer(),
        new web3_js_1.PublicKey(mint.publicKey).toBuffer(),
        Buffer.from(mpl_token_metadata_1.MasterEdition.EDITION_PREFIX),
    ], mpl_token_metadata_1.MetadataProgram.PUBKEY);
    const masterEditionTx = new mpl_token_metadata_1.CreateMasterEdition({ feePayer: payer.publicKey }, {
        edition,
        metadata: metadataPDA,
        updateAuthority: payer.publicKey,
        mint: mint.publicKey,
        mintAuthority: payer.publicKey,
    });
    const masterEditionRes = await transactionHandler.sendAndConfirmTransaction(masterEditionTx, [], {
        skipPreflight: false,
    });
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, masterEditionRes.txConfirmed);
    return { tokenAccount, edition, editionBump, mint, metadata: metadataPDA };
}
exports.mintNFT = mintNFT;
//# sourceMappingURL=mintNft.js.map