"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bn_js_1 = __importDefault(require("bn.js"));
const tape_1 = __importDefault(require("tape"));
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const utils_1 = require("../src/utils");
const transactions_1 = require("./transactions");
const utils_2 = require("./utils");
const actions_1 = require("./actions");
(0, utils_2.killStuckProcess)();
(0, tape_1.default)('buy: successful purchase for newly minted treasury mint', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000);
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: startDate + 5 * 20,
        mutable: true,
        price: 0.001,
        piecesInOneWallet: 1,
    };
    const { market, treasuryHolder } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    const buyRes = await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)('buy:: successful purchase');
    (0, amman_1.assertConfirmedTransaction)(t, buyRes.txConfirmed);
});
//# sourceMappingURL=buy.test.js.map