"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bn_js_1 = __importDefault(require("bn.js"));
const tape_1 = __importDefault(require("tape"));
const spl_token_1 = require("@solana/spl-token");
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const utils_1 = require("../src/utils");
const actions_1 = require("./actions");
const transactions_1 = require("./transactions");
const utils_2 = require("./utils");
(0, utils_2.killStuckProcess)();
(0, tape_1.default)('claim resource: success', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint, primaryMetadataCreators, } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000) + 1;
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: null,
        mutable: true,
        price: 1,
        piecesInOneWallet: 1,
    };
    const { market, treasuryHolder, treasuryOwnerBump, treasuryOwner } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    await (0, utils_2.sleep)(3000);
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    const buyRes = await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)('buy:: successful purchase');
    (0, amman_1.assertConfirmedTransaction)(t, buyRes.txConfirmed);
    await (0, utils_2.sleep)(3000);
    const marketTx = await (0, transactions_1.closeMarket)({
        transactionHandler,
        payer,
        connection,
        market,
    });
    const marketRes = await transactionHandler.sendAndConfirmTransaction(marketTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)(`market: ${market.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(t, marketRes.txConfirmed);
    const [payoutTicket, payoutTicketBump] = await (0, utils_1.findPayoutTicketAddress)(market.publicKey, payer.publicKey);
    const destination = await spl_token_1.Token.getAssociatedTokenAddress(spl_token_1.ASSOCIATED_TOKEN_PROGRAM_ID, spl_token_1.TOKEN_PROGRAM_ID, treasuryMint.publicKey, payer.publicKey);
    const metadata = await mpl_token_metadata_1.Metadata.getPDA(resourceMint.publicKey);
    const withdrawTx = await (0, transactions_1.createWithdrawTransaction)({
        connection,
        payer,
        market: market.publicKey,
        sellingResource: sellingResource.publicKey,
        metadata,
        treasuryHolder: treasuryHolder.publicKey,
        treasuryMint: treasuryMint.publicKey,
        destination,
        payoutTicket,
        payoutTicketBump,
        treasuryOwnerBump,
        treasuryOwner,
        primaryMetadataCreators,
    });
    const withdrawRes = await transactionHandler.sendAndConfirmTransaction(withdrawTx, [payer], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(t, withdrawRes.txConfirmed);
    const { tokenAccount: claimToken, createTokenTx } = await (0, transactions_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: resourceMint.publicKey,
        connection,
    });
    const claimTokenRes = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [claimToken], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(t, claimTokenRes.txConfirmed);
    const claimResourceTx = await (0, transactions_1.createClaimResourceTransaction)({
        connection,
        payer,
        market: market.publicKey,
        sellingResource: sellingResource.publicKey,
        metadata,
        treasuryHolder: treasuryHolder.publicKey,
        destination: claimToken.publicKey,
        vault: vault.publicKey,
        vaultOwnerBump,
        owner: vaultOwner,
    });
    const claimResourceRes = await transactionHandler.sendAndConfirmTransaction(claimResourceTx, [payer], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(t, claimResourceRes.txConfirmed);
    const token = new spl_token_1.Token(connection, resourceMint.publicKey, spl_token_1.TOKEN_PROGRAM_ID, payer);
    const createdToken = await token.getAccountInfo(claimToken.publicKey);
    t.assert(createdToken.mint.toBase58() === resourceMint.publicKey.toBase58());
    t.assert(createdToken.owner.toBase58() === payer.publicKey.toBase58());
});
(0, tape_1.default)('claim resource:  should fail due to the treasury not empty', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000) + 1;
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: null,
        mutable: true,
        price: 1,
        piecesInOneWallet: 1,
    };
    const { market, treasuryHolder } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    await (0, utils_2.sleep)(3000);
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    const buyRes = await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)('buy:: successful purchase');
    (0, amman_1.assertConfirmedTransaction)(t, buyRes.txConfirmed);
    await (0, utils_2.sleep)(3000);
    const marketTx = await (0, transactions_1.closeMarket)({
        transactionHandler,
        payer,
        connection,
        market,
    });
    const marketRes = await transactionHandler.sendAndConfirmTransaction(marketTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)(`market: ${market.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(t, marketRes.txConfirmed);
    const metadata = await mpl_token_metadata_1.Metadata.getPDA(resourceMint.publicKey);
    const { tokenAccount: claimToken, createTokenTx } = await (0, transactions_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: resourceMint.publicKey,
        connection,
    });
    const claimTokenRes = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [claimToken], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(t, claimTokenRes.txConfirmed);
    const claimResourceTx = await (0, transactions_1.createClaimResourceTransaction)({
        connection,
        payer,
        market: market.publicKey,
        sellingResource: sellingResource.publicKey,
        metadata,
        treasuryHolder: treasuryHolder.publicKey,
        destination: claimToken.publicKey,
        vault: vault.publicKey,
        vaultOwnerBump,
        owner: vaultOwner,
    });
    try {
        await transactionHandler.sendAndConfirmTransaction(claimResourceTx, [payer], amman_1.defaultSendOptions);
    }
    catch (error) {
        (0, utils_2.logDebug)(`expected transaction to fail due to 'treasury not empty'`);
        (0, amman_1.assertError)(t, error, [/0x178a/i]);
    }
});
//# sourceMappingURL=claimResource.test.js.map