"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const actions_1 = require("./actions");
const amman_1 = require("@metaplex-foundation/amman");
const utils_1 = require("./utils");
const transactions_1 = require("./transactions");
const src_1 = require("../src");
(0, utils_1.killStuckProcess)();
tape_1.default.skip('close-market: success', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000) + 2;
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: null,
        mutable: true,
        price: 1,
        piecesInOneWallet: 1,
    };
    const { market } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    await (0, utils_1.sleep)(3000);
    const marketTx = await (0, transactions_1.closeMarket)({
        transactionHandler,
        payer,
        connection,
        market,
    });
    const MarketRes = await transactionHandler.sendAndConfirmTransaction(marketTx, [payer], amman_1.defaultSendOptions);
    (0, utils_1.logDebug)(`market: ${market.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(t, MarketRes.txConfirmed);
    const marketAccount = await connection.getAccountInfo(market.publicKey);
    const [marketData] = src_1.MarketAccountData.deserialize(marketAccount === null || marketAccount === void 0 ? void 0 : marketAccount.data);
    t.assert('Ended' === marketData.state.toString());
});
(0, tape_1.default)('close-market: should fail when the market has the specific endDate', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000) + 2;
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: startDate + 4000,
        mutable: true,
        price: 1,
        piecesInOneWallet: 1,
    };
    const { market } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    await (0, utils_1.sleep)(3000);
    const marketTx = await (0, transactions_1.closeMarket)({
        transactionHandler,
        payer,
        connection,
        market,
    });
    (0, utils_1.logDebug)(`market: ${market.publicKey}`);
    try {
        await transactionHandler.sendAndConfirmTransaction(marketTx, [payer], amman_1.defaultSendOptions);
    }
    catch (error) {
        (0, utils_1.logDebug)('expected transaction to fail due to limited market duration ');
        (0, amman_1.assertError)(t, error, [/0x1782/i]);
    }
});
//# sourceMappingURL=closeMarket.test.js.map