"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBuyTransaction = void 0;
const web3_js_1 = require("@solana/web3.js");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const instructions_1 = require("../../src/generated/instructions");
const createBuyTransaction = async ({ connection, buyer, userTokenAccount, resourceMintMetadata, resourceMintEditionMarker, resourceMintMasterEdition, sellingResource, tradeHistory, tradeHistoryBump, market, marketTreasuryHolder, vault, vaultOwner, vaultOwnerBump, newMint, newMintEdition, newMintMetadata, newTokenAccount, }) => {
    const instruction = await (0, instructions_1.createBuyInstruction)({
        userWallet: buyer,
        userTokenAccount,
        editionMarker: resourceMintEditionMarker,
        masterEdition: resourceMintMasterEdition,
        masterEditionMetadata: resourceMintMetadata,
        vault,
        sellingResource,
        owner: vaultOwner,
        market,
        tradeHistory,
        treasuryHolder: marketTreasuryHolder,
        newMint,
        newMetadata: newMintMetadata,
        newEdition: newMintEdition,
        newTokenAccount,
        tokenMetadataProgram: mpl_token_metadata_1.MetadataProgram.PUBKEY,
    }, { tradeHistoryBump, vaultOwnerBump });
    const tx = new web3_js_1.Transaction();
    tx.add(instruction);
    tx.recentBlockhash = (await connection.getRecentBlockhash()).blockhash;
    tx.feePayer = buyer;
    return { tx };
};
exports.createBuyTransaction = createBuyTransaction;
//# sourceMappingURL=buy.js.map