"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTokenAccount = void 0;
const web3_js_1 = require("@solana/web3.js");
const spl_token_1 = require("@solana/spl-token");
const createTokenAccount = async ({ payer, mint, connection, owner, }) => {
    const tokenAccount = web3_js_1.Keypair.generate();
    const createTokenTx = new web3_js_1.Transaction();
    const accountRentExempt = await connection.getMinimumBalanceForRentExemption(spl_token_1.AccountLayout.span);
    createTokenTx.add(web3_js_1.SystemProgram.createAccount({
        fromPubkey: payer,
        newAccountPubkey: tokenAccount.publicKey,
        lamports: accountRentExempt,
        space: spl_token_1.AccountLayout.span,
        programId: new web3_js_1.PublicKey(spl_token_1.TOKEN_PROGRAM_ID),
    }));
    createTokenTx.add(spl_token_1.Token.createInitAccountInstruction(new web3_js_1.PublicKey(spl_token_1.TOKEN_PROGRAM_ID), mint, tokenAccount.publicKey, owner !== null && owner !== void 0 ? owner : payer));
    createTokenTx.recentBlockhash = (await connection.getRecentBlockhash()).blockhash;
    createTokenTx.feePayer = payer;
    createTokenTx.partialSign(tokenAccount);
    return {
        tokenAccount,
        createTokenTx,
    };
};
exports.createTokenAccount = createTokenAccount;
//# sourceMappingURL=createTokenAccount.js.map